@@ -26,21 +26,24 @@
 // lib
 #include "abstractcolumnstylist.h"
 
-namespace Okteta {
+
+namespace Okteta
+{
 
 class AbstractColumnStylistPrivate
 {
-public:
+  public:
     AbstractColumnStylistPrivate();
     ~AbstractColumnStylistPrivate();
 
-public:
+  public:
 
-private:
+  private:
 };
 
-inline AbstractColumnStylistPrivate::AbstractColumnStylistPrivate() = default;
-inline AbstractColumnStylistPrivate::~AbstractColumnStylistPrivate() = default;
+
+inline AbstractColumnStylistPrivate::AbstractColumnStylistPrivate() {}
+inline AbstractColumnStylistPrivate::~AbstractColumnStylistPrivate() {}
 
 }
 
