@@ -24,27 +24,29 @@
 #define SINT16_H
 
 // Qt
-#include <QMetaType>
-#include <QString>
+#include <QtCore/QMetaType>
+#include <QtCore/QString>
+
 
 struct SInt16
 {
-public:
-    SInt16(qint16 v);
+  public:
+    SInt16( qint16 v );
     SInt16();
 
-public:
+  public:
     QString toString() const;
 
-public:
-    qint16 value = 0;
+  public:
+    qint16 value;
 };
 
-inline SInt16::SInt16() = default;
-inline SInt16::SInt16(qint16 v) : value(v) {}
 
-inline QString SInt16::toString() const { return QString::number(value); }
+inline SInt16::SInt16() : value( 0 ) {}
+inline SInt16::SInt16( qint16 v ) : value( v ) {}
 
-Q_DECLARE_METATYPE(SInt16)
+inline QString SInt16::toString() const { return QString::number( value ); }
+
+Q_DECLARE_METATYPE( SInt16 )
 
 #endif
